==> zio-aws-route53recoverycontrolconfig_3-5.17.129.3-sources.jar: zio/aws/route53recoverycontrolconfig/model/DeleteControlPanelRequest.scala <==
package zio.aws.route53recoverycontrolconfig.model
import zio.aws.route53recoverycontrolconfig.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DeleteControlPanelRequest(controlPanelArn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteControlPanelRequest = {
    import DeleteControlPanelRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteControlPanelRequest
      .builder()
      .controlPanelArn(__string.unwrap(controlPanelArn): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.route53recoverycontrolconfig.model.DeleteControlPanelRequest.ReadOnly =
    zio.aws.route53recoverycontrolconfig.model.DeleteControlPanelRequest
      .wrap(buildAwsValue())
}
object DeleteControlPanelRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteControlPanelRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53recoverycontrolconfig.model.DeleteControlPanelRequest =
      zio.aws.route53recoverycontrolconfig.model
        .DeleteControlPanelRequest(controlPanelArn)
    def controlPanelArn: __string
    def getControlPanelArn: ZIO[Any, Nothing, __string] =
      ZIO.succeed(controlPanelArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteControlPanelRequest
  ) extends zio.aws.route53recoverycontrolconfig.model.DeleteControlPanelRequest.ReadOnly {
    override val controlPanelArn: __string =
      zio.aws.route53recoverycontrolconfig.model.primitives
        .__string(impl.controlPanelArn())
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteControlPanelRequest
  ): zio.aws.route53recoverycontrolconfig.model.DeleteControlPanelRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-route53recoverycontrolconfig_3-5.17.158.2-sources.jar: zio/aws/route53recoverycontrolconfig/model/DeleteControlPanelRequest.scala <==
package zio.aws.route53recoverycontrolconfig.model
import zio.aws.route53recoverycontrolconfig.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DeleteControlPanelRequest(controlPanelArn: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteControlPanelRequest = {
    import DeleteControlPanelRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteControlPanelRequest
      .builder()
      .controlPanelArn(controlPanelArn: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.route53recoverycontrolconfig.model.DeleteControlPanelRequest.ReadOnly =
    zio.aws.route53recoverycontrolconfig.model.DeleteControlPanelRequest
      .wrap(buildAwsValue())
}
object DeleteControlPanelRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteControlPanelRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53recoverycontrolconfig.model.DeleteControlPanelRequest =
      zio.aws.route53recoverycontrolconfig.model
        .DeleteControlPanelRequest(controlPanelArn)
    def controlPanelArn: __string
    def getControlPanelArn: ZIO[Any, Nothing, __string] =
      ZIO.succeed(controlPanelArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteControlPanelRequest
  ) extends zio.aws.route53recoverycontrolconfig.model.DeleteControlPanelRequest.ReadOnly {
    override val controlPanelArn: __string = impl.controlPanelArn(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.DeleteControlPanelRequest
  ): zio.aws.route53recoverycontrolconfig.model.DeleteControlPanelRequest.ReadOnly =
    new Wrapper(impl)
}
